@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import logging
-from typing import Any
+from typing import Any, Dict
 
 import aiohttp
 
@@ -37,7 +37,7 @@ class GQLHandler(HandlerGQL):
         query: str,
         variables: dict[str, Any] | None = None,
         operation_name: str | None = None,
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         if query is None:
             raise Exception("GraphQL guery string MUST NOT be empty!")
         # Add Xplora® API headers
@@ -57,14 +57,11 @@ class GQLHandler(HandlerGQL):
 
     async def runAuthorizedGqlQuery_a(
         self, query: str, variables: dict[str, Any] | None = None, operation_name: str | None = None
-    ) -> dict[str, Any]:
-        # if self.accessToken is None and self.signup:
-        # await self.login_a(self._API_KEY, self._API_SECRET)
-        # raise Exception("You must first login to the Xplora® API.")
+    ) -> Dict[str, Any]:
         # Run GraphQL query and return
         return await self.runGqlQuery_a(query, variables, operation_name)
 
-    async def login_a(self, key, sec) -> dict[str, Any]:
+    async def login_a(self, key, sec) -> Dict[str, Any]:
         if key and sec:
             self._API_KEY = key
             self._API_SECRET = sec
@@ -111,7 +108,7 @@ class GQLHandler(HandlerGQL):
 
     ########## SECTION QUERY start ##########
 
-    async def askWatchLocate_a(self, wuid: str) -> dict[str, Any]:
+    async def askWatchLocate_a(self, wuid: str) -> Dict[str, Any]:
         data: dict[str, Any] = await self.runGqlQuery_a(gq.WATCH_Q.get("askLocateQ", ""), {"uid": wuid}, "AskWatchLocate")
         errors = data.get("errors", [])
         if errors:
@@ -121,7 +118,7 @@ class GQLHandler(HandlerGQL):
             return res
         return {"askWatchLocate": False}
 
-    async def getWatchUserContacts_a(self, wuid: str) -> dict[str, Any]:
+    async def getWatchUserContacts_a(self, wuid: str) -> Dict[str, Any]:
         # Contacts from ownUser
         data: dict[str, Any] = await self.runGqlQuery_a(gq.WATCH_Q.get("contactsQ", ""), {"uid": wuid}, "Contacts")
         errors = data.get("errors", [])
@@ -129,14 +126,14 @@ class GQLHandler(HandlerGQL):
             self.errors.append({"function": "getWatchUserContacts", "errors": errors})
         return data.get("data", {})
 
-    async def getWatches_a(self, wuid: str) -> dict[str, Any]:
+    async def getWatches_a(self, wuid: str) -> Dict[str, Any]:
         data: dict[str, Any] = await self.runGqlQuery_a(gq.WATCH_Q.get("watchesQ", ""), {"uid": wuid}, "Watches")
         errors = data.get("errors", [])
         if errors:
             self.errors.append({"function": "getWatches", "errors": errors})
         return data.get("data", {})
 
-    async def getSWInfo_a(self, qrCode: str) -> dict[str, Any]:
+    async def getSWInfo_a(self, qrCode: str) -> Dict[str, Any]:
         data: dict[str, Any] = await self.runGqlQuery_a(
             gq.WATCH_Q.get("checkByQrCodeQ", ""), {"qrCode": qrCode}, "CheckWatchByQrCode"
         )
@@ -145,7 +142,7 @@ class GQLHandler(HandlerGQL):
             self.errors.append({"function": "getSWInfo", "errors": errors})
         return data.get("data", {})
 
-    async def getWatchState_a(self, qrCode: str, qrt: str = "", qrc: str = "") -> dict[str, Any]:
+    async def getWatchState_a(self, qrCode: str, qrt: str = "", qrc: str = "") -> Dict[str, Any]:
         variables = {}
         if qrCode:
             variables["qrCode"] = qrCode
@@ -159,14 +156,14 @@ class GQLHandler(HandlerGQL):
             self.errors.append({"function": "getWatchState", "errors": errors})
         return data.get("data", {})
 
-    async def getWatchLastLocation_a(self, wuid: str) -> dict[str, Any]:
+    async def getWatchLastLocation_a(self, wuid: str) -> Dict[str, Any]:
         data: dict[str, Any] = await self.runGqlQuery_a(gq.WATCH_Q.get("locateQ", ""), {"uid": wuid}, "WatchLastLocate")
         errors = data.get("errors", [])
         if errors:
             self.errors.append({"function": "getWatchLastLocation", "errors": errors})
         return data.get("data", {})
 
-    async def trackWatch_a(self, wuid: str) -> dict[str, Any]:
+    async def trackWatch_a(self, wuid: str) -> Dict[str, Any]:
         # tracking time - seconds
         data: dict[str, Any] = await self.runGqlQuery_a(gq.WATCH_Q.get("trackQ", ""), {"uid": wuid}, "TrackWatch")
         errors = data.get("errors", [])
@@ -177,90 +174,90 @@ class GQLHandler(HandlerGQL):
             return res
         return {"trackWatch": -1}
 
-    async def getAlarmTime_a(self, wuid: str) -> dict[str, Any]:
+    async def getAlarmTime_a(self, wuid: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("alarmsQ", ""), {"uid": wuid}, "Alarms")).get("data", {})
 
-    async def getWifi_a(self, wuid: str) -> dict[str, Any]:
+    async def getWifi_a(self, wuid: str) -> Dict[str, Any]:
         # without function?
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("getWifisQ", ""), {"uid": wuid}, "GetWifis")).get("data", {})
 
-    async def unReadChatMsgCount_a(self, wuid: str) -> dict[str, Any]:
+    async def unReadChatMsgCount_a(self, wuid: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("unReadChatMsgCountQ", ""), {"uid": wuid}, "UnReadChatMsgCount")).get(
             "data", {}
         )
 
-    async def safeZones_a(self, wuid: str) -> dict[str, Any]:
+    async def safeZones_a(self, wuid: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("safeZonesQ", ""), {"uid": wuid}, "SafeZones")).get("data", {})
 
-    async def safeZoneGroups_a(self) -> dict[str, Any]:
+    async def safeZoneGroups_a(self) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("safeZoneGroupsQ", ""), {}, "SafeZoneGroups")).get("data", {})
 
-    async def silentTimes_a(self, wuid: str) -> dict[str, Any]:
+    async def silentTimes_a(self, wuid: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("silentTimesQ", ""), {"uid": wuid}, "SlientTimes")).get("data", {})
 
     async def chats_a(
         self, wuid: str, offset: int = 0, limit: int = 0, msgId: str = "", asObject=False
-    ) -> dict[str, Any] | Chats:
+    ) -> Dict[str, Any] | Chats:
         # ownUser id
         res: dict = await self.runGqlQuery_a(
             gq.WATCH_Q.get("chatsQ", ""), {"uid": wuid, "offset": offset, "limit": limit, "msgId": msgId}, "Chats"
         )
         if res.get("errors", None) or res.get("data", None) is None:
             if asObject:
-                _LOGGER.error(res.get("data", {}))
+                _LOGGER.error(res.get("errors", None))
                 return Chats.from_dict(res.get("data", {}))
             return {}
         if asObject:
             return Chats.from_dict(res.get("data", {}))
         return res.get("data", {})
 
-    async def fetchChatImage_a(self, wuid: str, msgId: str) -> dict[str, Any]:
+    async def fetchChatImage_a(self, wuid: str, msgId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gq.WATCH_Q.get("fetchChatImageQ", ""), {"uid": wuid, "msgId": msgId}, "FetchChatImage")
         ).get("data", {})
 
-    async def fetchChatMp3_a(self, wuid: str, msgId: str) -> dict[str, Any]:
+    async def fetchChatMp3_a(self, wuid: str, msgId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gq.WATCH_Q.get("fetchChatMp3Q", ""), {"uid": wuid, "msgId": msgId}, "FetchChatMp3")
         ).get("data", {})
 
-    async def fetchChatShortVideo_a(self, wuid: str, msgId: str) -> dict[str, Any]:
+    async def fetchChatShortVideo_a(self, wuid: str, msgId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.WATCH_Q.get("fetchChatShortVideoQ", ""), {"uid": wuid, "msgId": msgId}, "FetchChatShortVideo"
             )
         ).get("data", {})
 
-    async def fetchChatShortVideoCover_a(self, wuid: str, msgId: str) -> dict[str, Any]:
+    async def fetchChatShortVideoCover_a(self, wuid: str, msgId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.WATCH_Q.get("fetchChatShortVideoCoverQ", ""), {"uid": wuid, "msgId": msgId}, "FetchChatShortVideoCover"
             )
         ).get("data", {})
 
-    async def fetchChatVoice_a(self, wuid: str, msgId: str) -> dict[str, Any]:
+    async def fetchChatVoice_a(self, wuid: str, msgId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gq.WATCH_Q.get("fetchChatVoiceQ", ""), {"uid": wuid, "msgId": msgId}, "FetchChatVoice")
         ).get("data", {})
 
-    async def watchImei_a(self, imei: str, qrCode: str, deviceKey: str) -> dict[str, Any]:
+    async def watchImei_a(self, imei: str, qrCode: str, deviceKey: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.WATCH_Q.get("imeiQ", ""), {"imei": imei, "qrCode": qrCode, "deviceKey": deviceKey}, "WatchImei"
             )
         ).get("data", {})
 
-    async def getWatchLocHistory_a(self, wuid: str, date: int = None, tz: str = None, limit: int = 1) -> dict[str, Any]:
+    async def getWatchLocHistory_a(self, wuid: str, date: int = None, tz: str = None, limit: int = 1) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.WATCH_Q.get("locHistoryQ", ""), {"uid": wuid, "date": date, "tz": tz, "limit": limit}, "LocHistory"
             )
         ).get("data", {})
 
-    async def watchesDynamic_a(self) -> dict[str, Any]:
+    async def watchesDynamic_a(self) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCH_Q.get("watchesDynamicQ", ""), {}, "WatchesDynamic")).get("data", {})
 
-    async def coinHistory_a(self, wuid: str, start: int, end: int, type: str, offset: int, limit: int) -> dict[str, Any]:
+    async def coinHistory_a(self, wuid: str, start: int, end: int, type: str, offset: int, limit: int) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.XCOIN_Q.get("historyQ", ""),
@@ -269,21 +266,21 @@ class GQLHandler(HandlerGQL):
             )
         ).get("data", {})
 
-    async def reminders_a(self, wuid: str) -> dict[str, Any]:
+    async def reminders_a(self, wuid: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.XMOVE_Q.get("remindersQ", ""), {"uid": wuid}, "Reminders")).get("data", {})
 
-    async def groups_a(self, isCampaign: bool) -> dict[str, Any]:
+    async def groups_a(self, isCampaign: bool) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.CARD_Q.get("groupsQ", ""), {"isCampaign": isCampaign}, "CardGroups")).get(
             "data", {}
         )
 
-    async def dynamic_a(self) -> dict[str, Any]:
+    async def dynamic_a(self) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.CARD_Q.get("dynamicQ", ""), {}, "DynamicCards")).get("data", {})
 
-    async def staticCard_a(self) -> dict[str, Any]:
+    async def staticCard_a(self) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.CARD_Q.get("staticQ", ""), {}, "StaticCard")).get("data", {})
 
-    async def familyInfo_a(self, wuid: str, watchId: str, tz: str, date: int) -> dict[str, Any]:
+    async def familyInfo_a(self, wuid: str, watchId: str, tz: str, date: int) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.FAMILY_Q.get("infoQ", ""), {"uid": wuid, "watchId": watchId, "tz": tz, "date": date}, "FamilyInfo"
@@ -292,7 +289,7 @@ class GQLHandler(HandlerGQL):
 
     async def getMyTotalInfo_a(
         self, wuid: str, tz: str, date: int, start: int, end: int, type: str, offset: int, limit: int
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.MYINFO_Q.get("getMyTotalInfoQ", ""),
@@ -312,7 +309,7 @@ class GQLHandler(HandlerGQL):
 
     async def myInfoWithCoinHistory_a(
         self, wuid: str, start: int, end: int, tz: str, type: str, offset: int, limit: int
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.MYINFO_Q.get("coinHistoryQ", ""),
@@ -321,11 +318,11 @@ class GQLHandler(HandlerGQL):
             )
         ).get("data", {})
 
-    async def getMyInfo_a(self) -> dict[str, Any]:
+    async def getMyInfo_a(self) -> Dict[str, Any]:
         # Profil from login Account
         return (await self.runGqlQuery_a(gq.MYINFO_Q.get("readQ", ""), {}, "ReadMyInfo")).get("data", {})
 
-    async def readCampaignProfile_a(self, wuid: str) -> dict[str, Any]:
+    async def readCampaignProfile_a(self, wuid: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.MYINFO_Q.get("readCampaignProfileQ", ""),
@@ -333,10 +330,10 @@ class GQLHandler(HandlerGQL):
             )
         ).get("data", {})
 
-    async def getReviewStatus_a(self, wuid: str) -> dict[str, Any]:
+    async def getReviewStatus_a(self, wuid: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.REVIEW_Q.get("getStatusQ", ""), {"uid": wuid}, "GetReviewStatus")).get("data", {})
 
-    async def getWatchUserSteps_a(self, wuid: str, tz: str, date: int) -> dict[str, Any]:
+    async def getWatchUserSteps_a(self, wuid: str, tz: str, date: int) -> Dict[str, Any]:
         data: dict[str, Any] = await self.runGqlQuery_a(
             gq.STEP_Q.get("userQ", ""), {"uid": wuid, "tz": tz, "date": date}, "UserSteps"
         )
@@ -345,59 +342,59 @@ class GQLHandler(HandlerGQL):
             self.errors.append({"function": "getWatchUserSteps", "errors": errors})
         return data.get("data", {})
 
-    async def countries_a(self) -> dict[str, Any]:
+    async def countries_a(self) -> Dict[str, Any]:
         # Country Support
         return (await self.runGqlQuery_a(gq.UTILS_Q.get("countriesQ", ""), {}, "Countries")).get("data", {})
 
-    async def avatars_a(self, id: str) -> dict[str, Any]:
+    async def avatars_a(self, id: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.CAMPAIGN_Q.get("avatarsQ", ""), {"id": id}, "Avatars")).get("data", {})
 
-    async def getFollowRequestWatchCount_a(self) -> dict[str, Any]:
+    async def getFollowRequestWatchCount_a(self) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gq.CAMPAIGN_Q.get("followRequestWatchCountQ", ""), {}, "FollowRequestWatchCount")
         ).get("data", {})
 
-    async def campaigns_a(self, id: str, categoryId: str) -> dict[str, Any]:
+    async def campaigns_a(self, id: str, categoryId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gq.CAMPAIGN_Q.get("campaignsQ", ""), {"id": id, "categoryId": categoryId}, "Campaigns")
         ).get("data", {})
 
-    async def isSubscribed_a(self, id: str, wuid: str) -> dict[str, Any]:
+    async def isSubscribed_a(self, id: str, wuid: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gq.CAMPAIGN_Q.get("isSubscribedQ", ""), {"id": id, "uid": wuid}, "IsSubscribedCampaign")
         ).get("data", {})
 
-    async def subscribed_a(self, wuid: str, needDetail: bool) -> dict[str, Any]:
+    async def subscribed_a(self, wuid: str, needDetail: bool) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.CAMPAIGN_Q.get("subscribedQ", ""), {"uid": wuid, "needDetail": needDetail}, "SubscribedCampaign"
             )
         ).get("data", {})
 
-    async def ranks_a(self, campaignId: str) -> dict[str, Any]:
+    async def ranks_a(self, campaignId: str) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.CAMPAIGN_Q.get("ranksQ", ""), {"campaignId": campaignId}, "Ranks")).get("data", {})
 
-    async def conv360IDToO2OID_a(self, qid: str, deviceId: str) -> dict[str, Any]:
+    async def conv360IDToO2OID_a(self, qid: str, deviceId: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gq.QUERY.get("conv360IDToO2OIDQ", ""), {"qid": qid, "deviceId": deviceId}, "Conv360IDToO2OID"
             )
         ).get("data", {})
 
-    async def getAppVersion_a(self) -> dict[str, Any]:
+    async def getAppVersion_a(self) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.QUERY.get("getAppVersionQ", ""), {}, "GetAppVersion")).get("data", {})
 
-    async def watchGroups_a(self, id: str = "") -> dict[str, Any]:
+    async def watchGroups_a(self, id: str = "") -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gq.WATCHGROUP_Q.get("watchGroupsQ", ""), {"id": id}, "WatchGroups")).get("data", {})
 
-    async def getStartTrackingWatch_a(self, wuid: str) -> dict[str, Any]:
+    async def getStartTrackingWatch_a(self, wuid: str) -> Dict[str, Any]:
         data = await self.runGqlQuery_a(gq.WATCH_Q.get("startTrackingWatchQ", ""), {"uid": wuid}, "StartTrackingWatch")
         errors: list[dict[str, str]] = data.get("errors", [])
         if errors:
             self.errors.append({"function": "getStartTrackingWatch", "error": errors})
         return data.get("data", {})
 
-    async def getEndTrackingWatch_a(self, wuid: str) -> dict[str, Any]:
+    async def getEndTrackingWatch_a(self, wuid: str) -> Dict[str, Any]:
         data = await self.runGqlQuery_a(gq.WATCH_Q.get("endTrackingWatchQ", ""), {"uid": wuid}, "EndTrackingWatch")
         errors: list[dict[str, str]] = data.get("errors", [])
         if errors:
@@ -406,7 +403,7 @@ class GQLHandler(HandlerGQL):
 
     async def checkEmailOrPhoneExist_a(
         self, type: UserContactType, email: str = "", countryCode: str = "", phoneNumber: str = ""
-    ) -> dict[str, bool]:
+    ) -> Dict[str, bool]:
         data: dict[str, dict[str, bool]] = await self.runGqlQuery_a(
             gq.UTILS_Q.get("checkEmailOrPhoneExistQ", ""),
             {"type": type.value, "email": email, "countryCode": countryCode, "phoneNumber": phoneNumber},
@@ -426,7 +423,7 @@ class GQLHandler(HandlerGQL):
             return True
         return False
 
-    async def addStep_a(self, stepCount: int) -> dict[str, Any]:
+    async def addStep_a(self, stepCount: int) -> Dict[str, Any]:
         return (await self.runGqlQuery_a(gm.STEP_M.get("addM", ""), {"stepCount": stepCount}, "AddStep")).get("data", {})
 
     async def shutdown_a(self, wuid: str) -> bool:
@@ -437,30 +434,30 @@ class GQLHandler(HandlerGQL):
         # ownUser id
         return await self.isAdmin_a(wuid, gm.WATCH_M.get("rebootM", ""), {"uid": wuid}, "reboot")
 
-    async def modifyAlert_a(self, id: str, yesOrNo: str) -> dict[str, Any]:
+    async def modifyAlert_a(self, id: str, yesOrNo: str) -> Dict[str, Any]:
         # function?
         return await self.runGqlQuery_a(gm.WATCH_M.get("modifyAlertM", ""), {"uid": id, "remind": yesOrNo}, "modifyAlert")
 
-    async def setEnableSilentTime_a(self, silentId: str, status: str = NormalStatus.ENABLE.value) -> dict[str, Any]:
+    async def setEnableSilentTime_a(self, silentId: str, status: str = NormalStatus.ENABLE.value) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gm.WATCH_M.get("setEnableSlientTimeM", ""), {"silentId": silentId, "status": status}, "SetEnableSlientTime"
             )
         ).get("data", {})
 
-    async def setEnableAlarmTime_a(self, alarmId: str, status: str = NormalStatus.ENABLE.value) -> dict[str, Any]:
+    async def setEnableAlarmTime_a(self, alarmId: str, status: str = NormalStatus.ENABLE.value) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(gm.WATCH_M.get("modifyAlarmM", ""), {"alarmId": alarmId, "status": status}, "ModifyAlarm")
         ).get("data", {})
 
-    async def setReadChatMsg_a(self, wuid: str, msgId: str, id: str) -> dict[str, Any]:
+    async def setReadChatMsg_a(self, wuid: str, msgId: str, id: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gm.WATCH_M.get("setReadChatMsgM", ""), {"uid": wuid, "msgId": msgId, "id": id}, "setReadChatMsg"
             )
         ).get("data", {})
 
-    async def submitIncorrectLocationData_a(self, wuid: str, lat: str, lng: str, timestamp: str) -> dict[str, Any]:
+    async def submitIncorrectLocationData_a(self, wuid: str, lat: str, lng: str, timestamp: str) -> Dict[str, Any]:
         return (
             await self.runGqlQuery_a(
                 gm.WATCH_M.get("submitIncorrectLocationDataM", ""),
@@ -469,7 +466,7 @@ class GQLHandler(HandlerGQL):
             )
         ).get("data", {})
 
-    async def modifyContact_a(self, contactId: str, isAdmin: bool, contactName: str = "", fileId: str = "") -> dict[str, Any]:
+    async def modifyContact_a(self, contactId: str, isAdmin: bool, contactName: str = "", fileId: str = "") -> Dict[str, Any]:
         return await self.runGqlQuery_a(
             gm.WATCH_M.get("modifyContactM", ""),
             {"contactId": contactId, "contactName": contactName, "fileId": fileId, "isAdmin": isAdmin},
@@ -484,7 +481,7 @@ class GQLHandler(HandlerGQL):
         countryCode: str = "",
         previousToken: str = "",
         lang: str = "",
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         return await self.runGqlQuery_a(
             gm.SIGN_M.get("issueEmailOrPhoneCodeM", ""),
             {
@@ -507,7 +504,7 @@ class GQLHandler(HandlerGQL):
         name: str = "",
         emailAddress: str = "",
         emailConsent: int = -1,
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         return await self.runGqlQuery_a(
             gm.SIGN_M.get("signUpWithEmailAndPhoneV2M", ""),
             {
@@ -521,7 +518,7 @@ class GQLHandler(HandlerGQL):
             "SignUpWithEmailAndPhoneV2",
         )
 
-    async def verifyCaptcha_a(self, captchaString: str = "", type: str = "") -> dict[str, Any]:
+    async def verifyCaptcha_a(self, captchaString: str = "", type: str = "") -> Dict[str, Any]:
         return await self.runGqlQuery_a(
             gm.SIGN_M.get("verifyCaptchaM", ""), {"captchaString": captchaString, "type": type}, "verifyCaptcha"
         )
@@ -534,7 +531,7 @@ class GQLHandler(HandlerGQL):
         countryCode: str = "",
         verifyCode: str = "",
         verificationToken: str = "",
-    ) -> dict[str, Any]:
+    ) -> Dict[str, Any]:
         return await self.runGqlQuery_a(
             gm.SIGN_M.get("verifyEmailOrPhoneCodeM", ""),
             {
